#! /usr/bin/python
# -*- coding: utf-8 -*-

# Copyright 2009-2020  NVIDIA Corporation.  All rights reserved.
#
# NOTICE TO USER:
#
# This source code is subject to NVIDIA ownership rights under U.S. and
# international Copyright laws.
#
# This software and the information contained herein is PROPRIETARY and
# CONFIDENTIAL to NVIDIA and is being provided under the terms and conditions
# of a form of NVIDIA software license agreement.
#
# NVIDIA MAKES NO REPRESENTATION ABOUT THE SUITABILITY OF THIS SOURCE
# CODE FOR ANY PURPOSE.  IT IS PROVIDED "AS IS" WITHOUT EXPRESS OR
# IMPLIED WARRANTY OF ANY KIND.  NVIDIA DISCLAIMS ALL WARRANTIES WITH
# REGARD TO THIS SOURCE CODE, INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY, NONINFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE.
# IN NO EVENT SHALL NVIDIA BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL,
# OR CONSEQUENTIAL DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS
# OF USE, DATA OR PROFITS,  WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
# OR OTHER TORTIOUS ACTION,  ARISING OUT OF OR IN CONNECTION WITH THE USE
# OR PERFORMANCE OF THIS SOURCE CODE.
#
# U.S. Government End Users.   This source code is a "commercial item" as
# that term is defined at  48 C.F.R. 2.101 (OCT 1995), consisting  of
# "commercial computer  software"  and "commercial computer software
# documentation" as such terms are  used in 48 C.F.R. 12.212 (SEPT 1995)
# and is provided to the U.S. Government only as a commercial end item.
# Consistent with 48 C.F.R.12.212 and 48 C.F.R. 227.7202-1 through
# 227.7202-4 (JUNE 1995), all U.S. Government End Users acquire the
# source code with only those rights set forth herein.
#
# Any use of this source code in individual and commercial software must
# include, in the user documentation and internal comments to the code,
# the above Disclaimer and U.S. Government End Users Notice.

import os
import sys

NSYS_CLI_DIR = os.path.join(
    os.path.dirname(os.path.realpath(__file__)),
    "nsys_cli_dist"
)


NSYS_BINARY = os.path.join(NSYS_CLI_DIR, "target-linux-x64/nsys")


CUSTOM_LD_LIBRARY_PATH = os.getenv('LD_LIBRARY_PATH', None)
CUSTOM_LD_LIBRARY_PATH = "{}:{}:{}".format(
    CUSTOM_LD_LIBRARY_PATH + ":" if CUSTOM_LD_LIBRARY_PATH is not None else "",
    "{}/host-linux-x64".format(NSYS_CLI_DIR),
    "{}/target-linux-x64".format(NSYS_CLI_DIR),
)


CUSTOM_PATH = "{}:{}".format(
    os.getenv('PATH', ""),
    "{}/target-linux-x64".format(NSYS_CLI_DIR)
)


def launch_command(binary, args, env):
    os.execve(binary, args, env)


def main():
    custom_env = os.environ.copy()
    custom_env["LD_LIBRARY_PATH"] = CUSTOM_LD_LIBRARY_PATH
    custom_env["PATH"] = CUSTOM_PATH
    launch_command(NSYS_BINARY, sys.argv, env=custom_env)


if __name__ == "__main__":
    sys.exit(main())
